==> freecad_0.9.2646.5.orig.tar.gz: FreeCAD-0.9.2646/src/Mod/Complete/App/CompleteConfiguration.h <==
/***************************************************************************
 *   Copyright (c) 2008 Jrgen Riegel (juergen.riegel@web.de)              *
 *                                                                         *
 *   This file is part of the FreeCAD CAx development system.              *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Library General Public           *
 *   License as published by the Free Software Foundation; either          *
 *   version 2 of the License, or (at your option) any later version.      *
 *                                                                         *
 *   This library  is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU Library General Public License for more details.                  *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this library; see the file COPYING.LIB. If not,    *
 *   write to the Free Software Foundation, Inc., 59 Temple Place,         *
 *   Suite 330, Boston, MA  02111-1307, USA                                *
 *                                                                         *
 ***************************************************************************/


#ifndef __CompleteConfiguration_h__
#define __CompleteConfiguration_h__

#include <FCConfig.h>

// Exporting of App classes
#ifdef FC_OS_WIN32
#    define COMPLETE_SHOW_SKETCHER
#    define COMPLETE_USE_DRAFTING
#else // for Linux
#    define COMPLETE_USE_DRAFTING
#endif




#endif

==> freecad_0.10.3247.dfsg.orig.tar.gz: FreeCAD-0.10.3247/src/Mod/Complete/App/CompleteConfiguration.h <==
/***************************************************************************
 *   Copyright (c) 2008 Jrgen Riegel (juergen.riegel@web.de)              *
 *                                                                         *
 *   This file is part of the FreeCAD CAx development system.              *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Library General Public           *
 *   License as published by the Free Software Foundation; either          *
 *   version 2 of the License, or (at your option) any later version.      *
 *                                                                         *
 *   This library  is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU Library General Public License for more details.                  *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this library; see the file COPYING.LIB. If not,    *
 *   write to the Free Software Foundation, Inc., 59 Temple Place,         *
 *   Suite 330, Boston, MA  02111-1307, USA                                *
 *                                                                         *
 ***************************************************************************/


#ifndef COMPLETE_CONFIGURATION_H
#define COMPLETE_CONFIGURATION_H

#include <FCConfig.h>

// Exporting of App classes
#ifdef FC_OS_WIN32
#    define COMPLETE_SHOW_SKETCHER
#    define COMPLETE_USE_DRAFTING
#else // for Linux
#    define COMPLETE_USE_DRAFTING
#endif




#endif
